==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/files_external/l10n/pt_PT.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "O pedido de obtenção falhou. Verifique se a sua chave da app Dropbox e o segredo estão corretos.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "O pedido de obtenção falhou. Verifique se a sua chave da app Dropbox e o segredo estão corretos.",
    "Please provide a valid Dropbox app key and secret." : "Por favor, forneça uma chave da app e o segredo da Dropbox válidos.",
    "Step 1 failed. Exception: %s" : "Passo 1 falhou. Exceção: %s",
    "Step 2 failed. Exception: %s" : "Passo 2 falhou. Exceção: %s",
    "External storage" : "Armazenamento Externo",
    "Local" : "Local",
    "Location" : "Localização:",
    "Amazon S3" : "Amazon S3",
    "Key" : "Chave",
    "Secret" : "Secreto",
    "Bucket" : "Bucket",
    "Amazon S3 and compliant" : "Amazon S3 e compatível",
    "Access Key" : "Chave de Acesso",
    "Secret Key" : "Chave Secreta",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "App key" : "Chave da App",
    "App secret" : "Chave secreta da aplicação",
    "Host" : "Anfitrião",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Remote subfolder" : "Subpasta remota ",
    "Secure ftps://" : "ftps:// Seguro",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Region (optional for OpenStack Object Storage)" : "Região (opcional para OpenStack Object Storage)",
    "API Key (required for Rackspace Cloud Files)" : "Chave API (necessário para Rackspace Cloud File)",
    "Tenantname (required for OpenStack Object Storage)" : "Nome do Serviço (necessário para OpenStack Object Storage)",
    "Password (required for OpenStack Object Storage)" : "Senha (necessária para OpenStack Object Storage)",
    "Service Name (required for OpenStack Object Storage)" : "Nome do Serviço (necessário para OpenStack Object Storage)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "Nome do Serviço (necessário para OpenStack Object Storage)",
    "Timeout of HTTP requests in seconds" : "Timeout de pedidos HTTP em segundos",
    "Share" : "Compartilhar",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizando o início de sessão OC",
    "Username as share" : "Utilizar nome de utilizador como partilha",
    "URL" : "URL",
    "Secure https://" : "https:// Seguro",
    "Access granted" : "Acesso autorizado",
    "Error configuring Dropbox storage" : "Erro ao configurar o armazenamento do Dropbox",
    "Grant access" : "Conceder acesso",
    "Error configuring Google Drive storage" : "Erro ao configurar o armazenamento do Google Drive",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "All users. Type to select user or group." : "Todos os utilizadores. Digite para selecionar o utilizador ou grupo.",
    "(group)" : "(grupo)",
    "Saved" : "Guardado",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "and" : "e",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte cURL no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte FTP no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O cliente\"%s\" não está instalado. Não é possível montar \"%s\" . Peça ao seu administrador para instalar.",
    "No external storage configured" : "Sem armazenamentos externos configurados",
    "You can configure external storages in the personal settings" : "Pode configurar os armazenamentos externos nas definições pessoais",
    "Name" : "Nome",
    "Storage type" : "Tipo de Armazenamento",
    "Scope" : "Âmbito",
    "External Storage" : "Armazenamento Externo",
    "Folder name" : "Nome da pasta",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Add storage" : "Adicionar armazenamento",
    "Delete" : "Apagar",
    "Enable User External Storage" : "Ativar Armazenamento Externo para o Utilizador",
    "Allow users to mount the following external storage" : "Permitir que os utilizadores montem o seguinte armazenamento externo"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_external/l10n/pt_PT.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "O pedido de obtenção falhou. Verifique se a sua chave da app Dropbox e o segredo estão corretos.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "O pedido de obtenção falhou. Verifique se a sua chave da app Dropbox e o segredo estão corretos.",
    "Please provide a valid Dropbox app key and secret." : "Por favor, forneça uma chave da app e o segredo da Dropbox válidos.",
    "Step 1 failed. Exception: %s" : "Passo 1 falhou. Exceção: %s",
    "Step 2 failed. Exception: %s" : "Passo 2 falhou. Exceção: %s",
    "External storage" : "Armazenamento Externo",
    "Local" : "Local",
    "Location" : "Localização:",
    "Amazon S3" : "Amazon S3",
    "Key" : "Chave",
    "Secret" : "Secreto",
    "Bucket" : "Bucket",
    "Amazon S3 and compliant" : "Amazon S3 e compatível",
    "Access Key" : "Chave de Acesso",
    "Secret Key" : "Chave Secreta",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "App key" : "Chave da App",
    "App secret" : "Chave secreta da aplicação",
    "Host" : "Anfitrião",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Remote subfolder" : "Subpasta remota ",
    "Secure ftps://" : "ftps:// Seguro",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Region (optional for OpenStack Object Storage)" : "Região (opcional para OpenStack Object Storage)",
    "API Key (required for Rackspace Cloud Files)" : "Chave API (necessário para Rackspace Cloud File)",
    "Tenantname (required for OpenStack Object Storage)" : "Nome do Serviço (necessário para OpenStack Object Storage)",
    "Password (required for OpenStack Object Storage)" : "Senha (necessária para OpenStack Object Storage)",
    "Service Name (required for OpenStack Object Storage)" : "Nome do Serviço (necessário para OpenStack Object Storage)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "Nome do Serviço (necessário para OpenStack Object Storage)",
    "Timeout of HTTP requests in seconds" : "Timeout de pedidos HTTP em segundos",
    "Share" : "Compartilhar",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizando o início de sessão OC",
    "Username as share" : "Utilizar nome de utilizador como partilha",
    "URL" : "URL",
    "Secure https://" : "https:// Seguro",
    "Public key" : "Chave pública",
    "Storage with id \"%i\" not found" : "Armazenamento com ID \"%i\" não encontrado",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Invalid storage backend \"%s\"" : "Backend de armazenamento inválido \"%s\"",
    "Access granted" : "Acesso autorizado",
    "Error configuring Dropbox storage" : "Erro ao configurar o armazenamento do Dropbox",
    "Grant access" : "Conceder acesso",
    "Error configuring Google Drive storage" : "Erro ao configurar o armazenamento do Google Drive",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "All users. Type to select user or group." : "Todos os utilizadores. Digite para selecionar o utilizador ou grupo.",
    "(group)" : "(grupo)",
    "Saved" : "Guardado",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar chave par",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "and" : "e",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte cURL no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte FTP no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O cliente\"%s\" não está instalado. Não é possível montar \"%s\" . Peça ao seu administrador para instalar.",
    "No external storage configured" : "Sem armazenamentos externos configurados",
    "You can add external storages in the personal settings" : "Pode adicionar armazenamentos externos nas definições pessoais",
    "Name" : "Nome",
    "Storage type" : "Tipo de Armazenamento",
    "Scope" : "Âmbito",
    "External Storage" : "Armazenamento Externo",
    "Folder name" : "Nome da pasta",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Add storage" : "Adicionar armazenamento",
    "Advanced settings" : "Definições avançadas",
    "Delete" : "Apagar",
    "Enable User External Storage" : "Ativar Armazenamento Externo para o Utilizador",
    "Allow users to mount the following external storage" : "Permitir que os utilizadores montem o seguinte armazenamento externo"
},
"nplurals=2; plural=(n != 1);");
